@@ -73,7 +73,7 @@ class DocumentPDFRenderer:
 
     def render(self):
         watermark_width = watermark_height = 0
-        watermark_filename = pkg_resources.resource_filename('reportbro', 'data/logo_watermark.png')
+        watermark_filename = pkg_resources.resource_filename('reportbro_plus', 'data/logo_watermark.png')
         if self.add_watermark:
             if not os.path.exists(watermark_filename):
                 self.add_watermark = False
@@ -402,8 +402,8 @@ class FPDFRB(fpdf.FPDF):
         fpdf.FPDF.__init__(self, orientation=orientation, unit='pt', format=dimension)
         self.x = 0
         self.y = 0
-        self.set_doc_option('core_fonts_encoding', 'windows-1252')
-        self.set_doc_option('encode_error_handling', encode_error_handling)
+        # self.set_doc_option('core_fonts_encoding', 'windows-1252')
+        # self.set_doc_option('encode_error_handling', encode_error_handling)
         self.loaded_images = dict()
         self.available_fonts = dict(
             courier=dict(standard_font=True),
